<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	if (!defined('_PS_VERSION_'))
		exit;
				
	require_once( _PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkAPI.php");
	require_once( _PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkJobManager.php");	
		
	/*
	 * exécution des travaux
	 *
	 */
	class PolarisLinkAPI_runModuleFrontController extends PolarisLinkAPI
	{
		private $Exit = [];

		public function __construct()
		{			
			$this->AuthByTokenAllowed = true;
			parent::__construct();
		}
		
		private function doJobs($links)
		{			
			foreach ($links as $link)
			{
				$startTime = microtime(true);

				$jobsManager = new PolarisLinkJobManager($link);
				$jobsManager->DebugMode = isset($_REQUEST['debug']);
				$jobsManager->run();
				
				$endTime = microtime(true);

				$returnMsg = sprintf("%s's jobs processed in %.2f\" with cache %s", $link->LinkName, $endTime - $startTime, $jobsManager->isUsingRefCache() ? "ON" : "OFF");
				$this->logDebug("Résultat de traitement du fichier d'import", $returnMsg);

				if (isset($_REQUEST['debug']))
					$this->Exit[] = $returnMsg;
			}
		}		
		
		protected function runAPI()
		{
			// Surtout plus de cache !!!
			Db::getInstance()->disableCache();

			if (isset($_REQUEST['debug']))
			{
				@ini_set('display_errors', '1');
				@ini_set('html_errors', '0');
				//@ini_set('error_log', 'xxx.log');
				
				@error_reporting(E_ALL | E_STRICT);				
				
				// Au revoir les interceptions Prestashop !!!
				set_error_handler(NULL);
				
				header("Content-Type: text/plain; charset=utf-8");
			}			

			$sites = $this->module->Config;
			
			if (Tools::getValue('wait') == 1)
			{				
				$this->doJobs($sites);
				$this->answerJSON($this->Exit);
			}
			else
			{
				if (!Configuration::get("POLARISLINK_CRON_DATAUPDATE") || isset($_REQUEST['debug']))
				{
					if ($this->AnswerAndContinueOffline([]))
					{										
						// On traite en arrière plan après avoir répondu
						ob_start();
						$this->doJobs($sites);
						ob_end_clean();
					}
					else
					{					
						// Autre solution, on est pas en fpm, on triche : on va appeler le api_run en curl sur un autre processus, ce qui va déclencher
						// un traitement en fond, non attaché à qqchose
						try
						{
							$ch = curl_init();

							$url = Tools::getHttpHost(true) . $_SERVER["REQUEST_URI"] .'&wait=1';

							// Configuration de l'URL et d'autres options
							$defaults = array(
								CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
								CURLOPT_URL => $url,
								CURLOPT_HEADER => 0,   
								CURLOPT_HTTPHEADER => [ 'Authorization: Basic '.base64_encode($this->Link->AccessKey) ], 
								CURLOPT_RETURNTRANSFER => TRUE,
								CURLOPT_TIMEOUT => 30
							);
							
							curl_setopt_array($ch, $defaults);

							// Récupération de l'URL et affichage sur le navigateur
							curl_exec($ch);						

							// Fermeture de la session cURL
							curl_close($ch);
						}
						catch (Exception $ex)
						{
							// pas grave
							$this->logError($ex);
						}
					}
				}
				else
				{
					// Ne rien faire !
					$this->answerJSON(array());
				}
			}
			
			// Appel métriques ?
			$this->module->sendMetrics();
		}
	}
 