<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	if (!defined('_PS_VERSION_'))
		exit;	
		
	function upgrade_module_0_1($module)
	{
		/*
			Création de la base de données
		*/
		$db = Db::getInstance();
	
		try
		{
			$refTables = array("manufacturer" => NULL, 
								"category" => "category",
								"tag_features" => "feature_value",
								"grtag_features" => "feature",
							);
			$dropTables = array(
								"polarislink_categories_map",
								"polarislink_jobs", 
								"polarislink_photos", 
								"polarislink_mails", 
								"polarislink_products_group", 
								"polarislink_sites", 
								"polarislink_ips_redir");
			
			foreach ($refTables as $table => $dest)
				$dropTables[] = "polarislink_ref_".$table;
							
			foreach ($dropTables as $table)	
				if (!$db->execute("DROP TABLE IF EXISTS `"._DB_PREFIX_.$table."` CASCADE")) 
					throw new Exception(sprintf("impossible de supprimer la table %s", $table));
					
			// Création des options
			if (!$db->execute("CREATE TABLE `"._DB_PREFIX_."polarislink_sites` (
							id_link INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,							
							cfg TEXT NOT NULL,
							lockname VARCHAR(200) NOT NULL DEFAULT '',
														
							PRIMARY KEY (id_link)
							) ENGINE="._MYSQL_ENGINE_." DEFAULT CHARSET=utf8;")) 
					throw new Exception("impossible de créer la table polarislink_sites");			
					
			/*------------------------------------------------------------
			* Table : polarislink_progress
			* contient les travaux à faire
			------------------------------------------------------------*/
			if (!$db->execute("CREATE TABLE `"._DB_PREFIX_."polarislink_jobs` (
							id_job INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
							id_link INT(10) UNSIGNED NOT NULL,
							job	 VARCHAR (255) NOT NULL,
							priority	 INT NOT NULL,
							creation_date INT NOT NULL,
							rows_done INT NOT NULL,
							total_rows INT NOT NULL,
							err INT NOT NULL,
							
							UNIQUE(job),
							PRIMARY KEY (id_job)
							) ENGINE="._MYSQL_ENGINE_." DEFAULT CHARSET=utf8;")) 
					throw new Exception("impossible de créer la table polarislink_jobs");
					
			if (!$db->execute("ALTER TABLE `"._DB_PREFIX_."polarislink_jobs` ADD CONSTRAINT `FK_polarislink_jobs_linkid` FOREIGN KEY (`id_link`) REFERENCES `"._DB_PREFIX_."polarislink_sites` (`id_link`) ON UPDATE CASCADE ON DELETE CASCADE;")) 
				throw new Exception(sprintf("impossible de lier la table %s à %s", "polarislink_jobs", "polarislink_sites"));	
			
			/*------------------------------------------------------------
			* Table : polarislink_images
			* contient les informations supplémentaires sur les photos
			------------------------------------------------------------*/
			if (!$db->execute("CREATE TABLE `"._DB_PREFIX_."polarislink_photos` (
							id_photos INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
							id_link INT(10) UNSIGNED NOT NULL,
							id_polaris INT(10) UNSIGNED NOT NULL,
							etag VARCHAR(256) NOT NULL,
							
							PRIMARY KEY (id_photos)
							) ENGINE="._MYSQL_ENGINE_." DEFAULT CHARSET=utf8;")) 
					throw new Exception("impossible de créer la table polarislink_photos");
					
					
			if (!$db->execute("ALTER TABLE `"._DB_PREFIX_."polarislink_photos` ADD CONSTRAINT `FK_polarislink_photos_linkid` FOREIGN KEY (`id_link`) REFERENCES `"._DB_PREFIX_."polarislink_sites` (`id_link`) ON UPDATE CASCADE ON DELETE CASCADE;")) 
				throw new Exception(sprintf("impossible de lier la table %s à %s", "polarislink_photos", "polarislink_sites"));	
					
			/*------------------------------------------------------------
			* Table : polarislink_ref_*
			* contient les travaux à faire
			------------------------------------------------------------*/
			foreach ($refTables as $table => $dest)
			{
				if (!$db->execute("CREATE TABLE `"._DB_PREFIX_."polarislink_ref_".$table."` (
							id_ps INT(10) UNSIGNED NOT NULL,
							id_link INT(10) UNSIGNED NOT NULL,
							id_polaris VARCHAR(100) NOT NULL,
														
							PRIMARY KEY (id_link, id_polaris)
							) ENGINE="._MYSQL_ENGINE_." DEFAULT CHARSET=utf8;")) 
					throw new Exception(sprintf("impossible de créer la table polarislink_ref_%s", $table));
					
				if (empty($dest))
					$dest = $table;
				if (!$db->execute("ALTER TABLE `"._DB_PREFIX_."polarislink_ref_".$table."` ADD CONSTRAINT `FK_"."polarislink_ref_".$table."` FOREIGN KEY (`id_ps`) REFERENCES `"._DB_PREFIX_.$dest."` (`id_".$dest."`) ON UPDATE CASCADE ON DELETE CASCADE;")) 
					throw new Exception(sprintf("impossible de lier la table %s à %s", "polarislink_ref_".$table, $dest));	
				
				if (!$db->execute("ALTER TABLE `"._DB_PREFIX_."polarislink_ref_".$table."` ADD CONSTRAINT `FK_polarislink_ref_".$table."_linkid` FOREIGN KEY (`id_link`) REFERENCES `"._DB_PREFIX_."polarislink_sites` (`id_link`) ON UPDATE CASCADE ON DELETE CASCADE;")) 
					throw new Exception(sprintf("impossible de lier la table %s à %s", "polarislink_ref_".$table, "polarislink_sites"));	
			}	

			// Création des mutations d'adresses mail
			if (!$db->execute("CREATE TABLE `"._DB_PREFIX_."polarislink_mails` (
							id_mail INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
							id_customer INT(10) UNSIGNED NOT NULL,
							mail VARCHAR(255) NOT NULL,
							mail_len INT(10) UNSIGNED NOT NULL,
														
							PRIMARY KEY (id_mail)
							) ENGINE="._MYSQL_ENGINE_." DEFAULT CHARSET=utf8;")) 
					throw new Exception("impossible de créer la table polarislink_mails");			
			if (!$db->execute("ALTER TABLE `"._DB_PREFIX_."polarislink_mails` ADD CONSTRAINT `FK_polarislink_mails` FOREIGN KEY (`id_customer`) REFERENCES `"._DB_PREFIX_."customer` (`id_customer`) ON UPDATE CASCADE ON DELETE CASCADE;")) 
					throw new Exception(sprintf("impossible de lier la table %s à %s", "polarislink_mails", "customer"));	


			// Création des références de produit croisé
			if (!$db->execute("CREATE TABLE `"._DB_PREFIX_."polarislink_products_group` (
							id_product INT(10) UNSIGNED NOT NULL,
							id_group INT(11) NOT NULL,							
														
							PRIMARY KEY (id_product)
							) ENGINE="._MYSQL_ENGINE_." DEFAULT CHARSET=utf8;")) 
					throw new Exception("impossible de créer la table polarislink_products_group");	
					
			if (!$db->execute("ALTER TABLE `"._DB_PREFIX_."polarislink_products_group` ADD CONSTRAINT `FK_polarislink_group` FOREIGN KEY (`id_product`) REFERENCES `"._DB_PREFIX_."product` (`id_product`) ON UPDATE CASCADE ON DELETE CASCADE;")) 
					throw new Exception(sprintf("impossible de lier la table %s à %s", "polarislink_products_group", "product"));	
		}
		catch (Exception $ex)
		{
			throw $ex;
		}
				
		return true;
	 }
 